@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
 #include <kgenericfactory.h>
 #include <kglobal.h>
@@ -26,6 +26,8 @@
 #include <interfaces/guiinterface.h>
 #include "logviewerplugin.h"
 #include "logviewer.h"
+#include "logprefpage.h"
+#include "logflags.h"
 
 #define NAME "logviewerplugin"
 #define AUTHOR "Joris Guisson"
@@ -39,7 +41,7 @@ namespace kt
 {
 
 	LogViewerPlugin::LogViewerPlugin(QObject* parent, const char* qt_name, const QStringList& args)
-	: Plugin(parent, qt_name, args, NAME, AUTHOR, EMAIL,i18n("KTorrent's log viewer plugin"))
+	: Plugin(parent, qt_name, args, NAME, AUTHOR, EMAIL,i18n("Shows logging output in a widget"))
 	{
 		lv = 0;
 	}
@@ -52,18 +54,29 @@ namespace kt
 	void LogViewerPlugin::load()
 	{
 		lv = new LogViewer();
-		this->getGUI()->addWidgetBelowView(lv);
-		bt::Log & lg = Out();
+		this->getGUI()->addWidgetBelowView(lv,"log",i18n("Log Viewer"));
+		bt::Log & lg = Globals::instance().getLog(0);
 		lg.addMonitor(lv);
+		pref = new LogPrefPage();
+		this->getGUI()->addPrefPage(pref);
 	}
 
 	void LogViewerPlugin::unload()
 	{
 		this->getGUI()->removeWidgetBelowView(lv);
-		bt::Log & lg = Out();
+		bt::Log & lg = Globals::instance().getLog(0);
 		lg.removeMonitor(lv);
 		delete lv;
 		lv = 0;
+		this->getGUI()->removePrefPage(pref);
+		delete pref;
+		pref = 0;
+		LogFlags::finalize();
+	}
+	
+	bool LogViewerPlugin::versionCheck(const QString & version) const
+	{
+		return version == KT_VERSION_MACRO;
 	}
 
 }
